@@ -16,8 +16,9 @@ __all__ = (
     "Inventory",
     "BackgroundSystemModel",
     "ExportInventory",
+    "VehicleInputParameters",
 )
-__version__ = (1, 0, 0)
+__version__ = (1, 0, 3)
 
 from pathlib import Path
 
@@ -29,3 +30,4 @@ from .export import ExportInventory
 from .hot_emissions import HotEmissionsModel
 from .inventory import Inventory
 from .noise_emissions import NoiseEmissionsModel
+from .vehicle_input_parameters import VehicleInputParameters
