@@ -89,38 +89,30 @@ class EnergyConsumptionModel:
         rho_air: float = 1.204,
         country: str = "CH",
     ) -> None:
+        if not isinstance(vehicle_size, list):
+            vehicle_size = [vehicle_size]
 
         self.rho_air = rho_air
-        self.cycle_name = (
-            cycle
-            if isinstance(cycle, str)
-            else get_default_driving_cycle_name(vehicle_type)
-        )
+
+        if isinstance(cycle, np.ndarray):
+            self.cycle_name = "custom"
+            self.cycle = cycle.reshape(-1, 1)
+
+            if gradient is not None:
+                self.gradient = gradient.reshape(-1, 1)
+            else:
+                self.gradient = np.zeros_like(self.cycle)
+
+        else:
+            self.cycle_name = cycle
+            self.cycle, self.gradient = get_standard_driving_cycle_and_gradient(
+                vehicle_type, vehicle_size, self.cycle_name
+            )
+
         self.country = country
         self.vehicle_type = vehicle_type
         self.vehicle_size = vehicle_size
 
-        # If a string is passed, the corresponding driving cycle is retrieved
-
-        if self.cycle_name:
-            try:
-                cycle, gradient = get_standard_driving_cycle_and_gradient(
-                    vehicle_type, vehicle_size, self.cycle_name
-                )
-
-            except KeyError as err:
-                raise KeyError(
-                    "The driving cycle specified could not be found."
-                ) from err
-        elif isinstance(cycle, np.ndarray):
-            self.cycle_name = "custom"
-
-        else:
-            raise TypeError("The format of the driving cycle is not valid.")
-
-        self.cycle = cycle
-        self.gradient = gradient
-
         if "Micro" in vehicle_size:
             idx = vehicle_size.index("Micro")
             self.cycle[:, idx] = np.clip(self.cycle[:, idx], 0, 90)
@@ -171,7 +163,6 @@ class EnergyConsumptionModel:
         ambient_temp,
         indoor_temp,
     ) -> tuple[Any, Any, Any, Any]:
-
         if ambient_temp is not None:
             ambient_temp = np.resize(ambient_temp, (12,))
         else:
@@ -248,7 +239,6 @@ class EnergyConsumptionModel:
         _o = lambda x: np.where(x == 0, 1, x)
 
         if hvac_power is not None:
-
             (
                 p_cooling,
                 p_heating,
@@ -288,7 +278,6 @@ class EnergyConsumptionModel:
         return auxiliary_energy / _o(efficiency).T
 
     def convert_to_xr(self, data):
-
         return xr.DataArray(
             data,
             dims=["second", "value", "year", "powertrain", "size", "parameter"],
