@@ -138,7 +138,6 @@ def get_dict_input() -> dict:
         reader = csv.reader(f, delimiter=";")
         raw = list(reader)
         for _r, r in enumerate(raw):
-
             if len(r) == 3:
                 r[1] = eval(r[1])
             raw[_r] = tuple(r)
@@ -170,7 +169,6 @@ class Inventory:
         indicator: str = "midpoint",
         functional_unit: str = "vkm",
     ) -> None:
-
         self.vm = vm
 
         self.scope = {
@@ -279,7 +277,7 @@ class Inventory:
 
         if sensitivity:
             # remove the `impact` dimension
-            response = response.squeeze("impact")
+            response = response.sum(dim="impact")
 
         return response
 
@@ -332,7 +330,6 @@ class Inventory:
         return list(idx_cats.keys()), list_ind
 
     def get_load_factor(self):
-
         # If the FU is in passenger-km, we normalize the results by
         # the number of passengers
         if self.func_unit == "vkm":
@@ -366,7 +363,6 @@ class Inventory:
         return load_factor
 
     def calculate_impacts(self, sensitivity=False):
-
         if self.scenario != "static":
             B = self.B.interp(
                 year=self.scope["year"], kwargs={"fill_value": "extrapolate"}
@@ -412,7 +408,13 @@ class Inventory:
             f_vector[a] = 1
             X = sparse.linalg.spsolve(sparse.csr_matrix(self.A[0]), f_vector.T)
 
-            new_arr[a] = (X * B).sum(axis=-1).T
+            _X = (X * B).sum(axis=-1).T
+
+            if _X.ndim == 1:
+                # add a trailing dimension
+                new_arr[a] = _X[:, None]
+            else:
+                new_arr[a] = _X
 
         new_arr = new_arr.transpose(1, 0, 2)
 
@@ -453,7 +455,7 @@ class Inventory:
 
         if sensitivity:
             results[...] = arr.sum(axis=-2)
-            results /= results.sel(parameter="reference")
+            results /= results.sel(value="reference")
         else:
             results[...] = arr
 
@@ -510,7 +512,6 @@ class Inventory:
         for size in self.scope["size"]:
             for powertrain in self.scope["powertrain"]:
                 for euro_class, year in zip(list_euro_classes, self.scope["year"]):
-
                     maximum += 1
 
                     if self.func_unit == "vkm":
@@ -813,7 +814,6 @@ class Inventory:
         return indices
 
     def add_electricity_infrastructure(self, dataset, losses):
-
         for y, year in enumerate(self.scope["year"]):
             # Add transmission network for high and medium voltage
             for input in [
@@ -1144,7 +1144,6 @@ class Inventory:
             ]
 
         elif find_input_by == "unit":
-
             ins = [
                 i
                 for i in ind_inputs
@@ -1216,7 +1215,6 @@ class Inventory:
         pass
 
     def add_fuel_cell_stack(self):
-
         self.A[
             :,
             self.find_input_indices(("Ancillary BoP",)),
@@ -1245,7 +1243,6 @@ class Inventory:
         )
 
     def add_hydrogen_tank(self):
-
         hydro_tank_type = self.vm.energy_storage.get(
             "hydrogen", {"tank type": "carbon fiber"}
         )["tank type"]
@@ -1267,7 +1264,6 @@ class Inventory:
         )
 
     def add_battery(self):
-
         # Start of printout
         print(
             "****************** IMPORTANT BACKGROUND PARAMETERS ******************",
@@ -1361,7 +1357,6 @@ class Inventory:
         )
 
     def add_cng_tank(self):
-
         index = self.get_index_vehicle_from_array("ICEV-g")
         self.A[
             :,
@@ -1376,7 +1371,6 @@ class Inventory:
         )
 
     def add_vehicle_to_transport_dataset(self):
-
         self.A[
             :,
             self.find_input_indices((f"{self.vm.vehicle_type.capitalize()}, ",)),
@@ -1386,9 +1380,22 @@ class Inventory:
         )
 
     def display_renewable_rate_in_mix(self):
-
         sum_renew = self.define_renewable_rate_in_mix()
 
+        use_year = (
+            (
+                self.array.values[self.array_inputs["lifetime kilometers"]]
+                / self.array.values[self.array_inputs["kilometers per year"]]
+            )
+            .reshape(
+                self.iterations,
+                len(self.scope["powertrain"]),
+                len(self.scope["size"]),
+                len(self.scope["year"]),
+            )
+            .mean(axis=(0, 1, 2))
+        ).mean()
+
         for y, year in enumerate(self.scope["year"]):
             if y + 1 == len(self.scope["year"]):
                 end_str = "\n * "
@@ -1396,12 +1403,11 @@ class Inventory:
                 end_str = "\n \t * "
 
             print(
-                f"in {year}, % of renewable: {np.round(sum_renew[y] * 100)}.",
+                f"between {year} and {int(year + use_year)}, % of renewable: {np.round(sum_renew[y] * 100)}.",
                 end=end_str,
             )
 
     def add_electricity_to_electric_vehicles(self) -> None:
-
         electric_powertrains = [
             "BEV",
             "BEV-opp",
@@ -1439,9 +1445,7 @@ class Inventory:
                 ]
 
     def add_hydrogen_to_fuel_cell_vehicles(self) -> None:
-
         if "FCEV" in self.scope["powertrain"]:
-
             index = self.get_index_vehicle_from_array("FCEV")
 
             print(
@@ -1478,17 +1482,12 @@ class Inventory:
                         (f"transport, {self.vm.vehicle_type}, ", "FCEV", str(year))
                     ),
                 ] = (
-                    self.array[self.array_inputs["fuel mass"], :, ind_array]
-                    / self.array[
-                        self.array_inputs[RANGE_PARAM[self.vm.vehicle_type]],
-                        :,
-                        ind_array,
-                    ]
+                    self.array[self.array_inputs["fuel consumption"], :, ind_array]
+                    * self.array[self.array_inputs["fuel density per kg"], :, ind_array]
                     * -1
                 )
 
     def display_fuel_blend(self, fuel) -> None:
-
         print(
             "{} is completed by {}.".format(
                 self.vm.fuel_blend[fuel]["primary"]["type"],
@@ -1511,7 +1510,6 @@ class Inventory:
     def add_carbon_dioxide_emissions(
         self, year, powertrain, powertrain_short, fossil_co2, biogenic_co2
     ) -> None:
-
         ind_array = [
             x
             for x in self.get_index_vehicle_from_array(year)
@@ -1552,7 +1550,6 @@ class Inventory:
         )
 
     def add_sulphur_emissions(self, year, fuel, powertrain_short, powertrains) -> None:
-
         # Fuel-based SO2 emissions
         # Sulfur concentration value for a given country, a given year, as concentration ratio
 
@@ -1562,7 +1559,6 @@ class Inventory:
         idx.extend(powertrain_short)
 
         if sulfur_concentration:
-
             self.A[
                 :,
                 self.inputs[("Sulfur dioxide", ("air",), "kilogram")],
@@ -1578,7 +1574,6 @@ class Inventory:
             )
 
     def add_fuel_to_vehicles(self, fuel, powertrains, powertrains_short) -> None:
-
         if [i for i in self.scope["powertrain"] if i in powertrains]:
             index = self.get_index_vehicle_from_array(powertrains)
             (
@@ -1589,7 +1584,6 @@ class Inventory:
             self.display_fuel_blend(fuel)
 
             for y, year in enumerate(self.scope["year"]):
-
                 ind_array = [
                     x for x in self.get_index_vehicle_from_array(year) if x in index
                 ]
@@ -1609,12 +1603,13 @@ class Inventory:
                         excludes=("battery",),
                     ),
                 ] = (
-                    self.array[self.array_inputs["fuel mass"], :, ind_array]
-                    / self.array[
-                        self.array_inputs[RANGE_PARAM[self.vm.vehicle_type]],
-                        :,
-                        ind_array,
-                    ]
+                    (
+                        self.array[self.array_inputs["fuel consumption"], :, ind_array]
+                        * self.array[
+                            self.array_inputs["fuel density per kg"], :, ind_array
+                        ]
+                        * -1
+                    )
                 ) * -1
 
                 self.add_carbon_dioxide_emissions(
@@ -1628,7 +1623,6 @@ class Inventory:
                 self.add_sulphur_emissions(year, fuel, [powertrains_short], powertrains)
 
     def add_road_maintenance(self) -> None:
-
         # Infrastructure maintenance
         self.A[
             :,
@@ -1639,7 +1633,6 @@ class Inventory:
         )
 
     def add_road_construction(self) -> None:
-
         # Infrastructure
         self.A[
             :,
@@ -1652,7 +1645,6 @@ class Inventory:
         )
 
     def add_exhaust_emissions(self) -> None:
-
         # Exhaust emissions
         # Non-fuel based emissions
         self.A[
@@ -1669,7 +1661,6 @@ class Inventory:
         )
 
     def add_noise_emissions(self) -> None:
-
         # Noise emissions
         self.A[
             np.ix_(
@@ -1685,7 +1676,6 @@ class Inventory:
         )
 
     def add_refrigerant_emissions(self) -> None:
-
         # Emissions of air conditioner refrigerant r134a
         # Leakage assumed to amount to 53g according to
         # https://treeze.ch/fileadmin/user_upload/downloads/Publications/Case_Studies/Mobility/544-LCI-Road-NonRoad-Transport-Services-v2.0.pdf
@@ -1755,7 +1745,6 @@ class Inventory:
             ).T
 
     def add_abrasion_emissions(self) -> None:
-
         # Non-exhaust emissions
 
         abrasion_datasets = {
@@ -1828,7 +1817,6 @@ class Inventory:
             and any([w for w in self.scope["year"] if str(w) in name])
             and any([w for w in self.scope["size"] if w in name])
         ):
-
             powertrain = [w for w in self.scope["powertrain"] if w in name][0]
             size = [w for w in self.scope["size"] if w in name][0]
             year = [w for w in self.scope["year"] if str(w) in name][0]
@@ -1866,12 +1854,17 @@ class Inventory:
         self.A[:, idx, idx] = 1
 
     def change_functional_unit(self) -> None:
-
         load_factor = self.get_load_factor()
         idx_cars = self.find_input_indices((f"transport, {self.vm.vehicle_type}, ",))
         idx_others = [i for i in range(self.A.shape[1]) if i not in idx_cars]
 
-        self.A[np.ix_(np.arange(self.iterations), idx_others, idx_cars,)] *= (
+        self.A[
+            np.ix_(
+                np.arange(self.iterations),
+                idx_others,
+                idx_cars,
+            )
+        ] *= (
             1 / load_factor
         ).reshape(-1, 1, len(idx_cars))
 
